/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.communication
 * File:    BasicClient.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.communication;

import java.net.Socket;

import javax.xml.bind.JAXBException;

import org.apache.commons.codec.binary.Base64;

import de.fhhannover.inform.iron.mapserver.communication.connections.ConnectionContainer;

public class BasicClient extends Client {
	
	private String mUsername;
	private Usermanager mUsermanager;
	private boolean mAuthorized;

	public BasicClient(Socket socket) throws JAXBException {
		super(socket);
		mUsermanager = Usermanager.getInstance();
		mAuthorized = false;
	}

	@Override
	protected boolean authorize(String value) {
		logger.debug("Client authorizing with '" + value + "'");
	
		String basicBase64 = value.substring(5);
		String basicDecoded = new String(Base64.decodeBase64(basicBase64.getBytes()));
		String[] userAndPass = basicDecoded.split(":");
		mUsername = new String(userAndPass[0]);
		
		mAuthorized = mUsermanager.checkBasicAuth(userAndPass[0], userAndPass[1]);
		
		if(mAuthorized) {
			logger.info("Accepted basic client with publisherID " + mUsername);
		} else {
			logger.info("Denied basic client with publisherID " + mUsername);
		}
			
		return mAuthorized;
	}

	@Override
	protected boolean isAuthorized() {
		return mAuthorized;
	}

	@Override
	protected String determinePublisherId() {
		return mUsername;
	}
}