/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.communication.services.ssrc
 * File:    DumpSessionReceive.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.communication.services.ssrc;

import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

import org.apache.log4j.Logger;
import org.trustedcomputinggroup._2010.ifmap._2.DumpRequestType;
import org.trustedcomputinggroup._2010.ifmap._2.DumpResponseType;
import org.trustedcomputinggroup._2010.ifmap._2.ResponseType;
import org.trustedcomputinggroup._2010.ifmap._2.SessionRequestType;

import de.fhhannover.inform.iron.mapserver.communication.DeprecatedDataModelServiceAccessor;
import de.fhhannover.inform.iron.mapserver.communication.connections.ConnectionContainer;
import de.fhhannover.inform.iron.mapserver.communication.services.ssrc.exceptions.SessionNotFoundException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.ParameterException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.PublisherConstructionException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.RunningSessionException;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.AccessRequest;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.Device;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.Identifier;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.Identity;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.IpAddress;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.MacAddress;
import de.fhhannover.inform.iron.mapserver.logging.Logging;
import de.fhhannover.inform.iron.mapserver.utils.IdentifierTransformer;

public class DumpSessionReceive {
	private static Logger logger;
	private static IdentifierTransformer iTrans = IdentifierTransformer.getInstance();
	static {
		logger = Logging.getTheLogger();
	}

	/**
	 * Transform a given identifier into an object of a autogenerated class
	 * and add it into the given ResultItemType object.
	 * 
	 * @param rit
	 * @param identifier
	 */
	private static void add(DumpResponseType rit, Identifier identifier) {
		if (identifier != null && rit != null) {
			List<Object> retlist = rit.getAccessRequestOrIdentityOrIpAddress();
			if (identifier instanceof AccessRequest) {				
				retlist.add(iTrans.transformAR((AccessRequest)identifier));
			} else if (identifier instanceof Device) {
				retlist.add(iTrans.transformDevice((Device)identifier));
			} else if (identifier instanceof Identity) {
				retlist.add(iTrans.transformIdentity((Identity)identifier));
			} else if (identifier instanceof IpAddress) {				
				retlist.add(iTrans.transformIP((IpAddress)identifier));
			} else if (identifier instanceof MacAddress) {
				retlist.add(iTrans.transformMacAddress((MacAddress)identifier));
			}
		}
	}
	
	
	public static ResponseType dump(DumpRequestType session)
	throws NoSuchAlgorithmException, SessionNotFoundException, 
	ParameterException, RunningSessionException, PublisherConstructionException{
		ConnectionContainer.getInstance().renewSession(session.getSessionId());
		String istr = session.getIdentifier();		
		ResponseType resp = new ResponseType();
    	DumpResponseType dt =  new DumpResponseType();
    	
    	Identifier[] idents = DeprecatedDataModelServiceAccessor.getDataModelServiceInstance().dump();
    	long last_update = DeprecatedDataModelServiceAccessor.getDataModelServiceInstance().getLastUpdateTimestamp();
    	
    	dt.setLastUpdate(""+last_update);
    	
    	if(istr == null)
    		istr = "";
    	else istr = istr.trim().toLowerCase();
    	
    	logger.info("DumpSessionReceive.dump(): identifier='"+istr+"'");
		if(istr.equals("") ||  istr.equals("*")){
			for(Identifier id : idents){    			
    			DumpSessionReceive.add(dt, id);
			}
		}
		else {		
			StringTokenizer tokenizer = new StringTokenizer(istr,",");
			ArrayList<String> list = new ArrayList<String>();
			while(tokenizer.hasMoreElements())
				list.add(tokenizer.nextToken());
		//ConnectionContainer.getInstance().renewSession(session.getSessionId());		    	
			if(!session.getIdentifier().equals("-")){
				for(Identifier id : idents){
					//Skip subscriptions
					if(id.getLinks().size() > 0){								
						if(list.contains(id.getType().getTypeString()))
							DumpSessionReceive.add(dt, id);    			
					}
				}
				logger.info("DumpSessionReceive.dump(): "+idents.length+" Identifier gefunden.");
			}
		}
    	
    	resp.setDumpResult(dt);
		return resp;
	}
}
