/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.communication.services.ssrc
 * File:    PublishReceive.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.communication.services.ssrc;

import java.io.IOException;
import java.security.NoSuchAlgorithmException;

import javax.xml.parsers.ParserConfigurationException;

import org.trustedcomputinggroup._2010.ifmap._2.PublishRequestType;
import org.trustedcomputinggroup._2010.ifmap._2.ResponseType;
import org.xml.sax.SAXException;

import de.fhhannover.inform.iron.mapserver.communication.DeprecatedDataModelServiceAccessor;
import de.fhhannover.inform.iron.mapserver.communication.connections.ConnectionContainer;
import de.fhhannover.inform.iron.mapserver.communication.services.ssrc.exceptions.SessionNotFoundException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.IdentifierConstructionException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.InvalidMetadataException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.MetadataConstructionException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.NoSuchPublisherException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.ParameterException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.RequestCreationException;
import de.fhhannover.inform.iron.mapserver.messages.PublishRequest;
import de.fhhannover.inform.iron.mapserver.utils.MessageTransformer;

/**
 * PublishReceive class
 * 
 * Manages the publish requests and pass the requests to the data model
 * 
 * @author dl
 * @version 0.1
 * 
 * created: 17.12.2009
 *
 * changes:
 *  10.04.2010 - throw MetadataConstructionException upwards
 *  04.03.2010 - cleanup, error responses
 *  14.02.2010 - cleanup, comments
 *  10.02.2010 - removed cast by getAccessRequest(), moved methods getIdentifier() and getIdentityType()
 *               to class IdentifierType
 *  07.02.2010 aw - added try catch for ParameterException
 *  05.02.2010 aw - transformed to use RequestFactory
 *  04.02.2010 - test to get JDOM Document out of XMLStreamReader, filter for publish, 
 *  03.02.2010 - refactoring ( methods getIdentifier() and getIdentityType() ), 
 *  			 publish delete and publish notify, imported StAXBuilder class to convert XMLStreamReader to JDOM Document
 *  28.01.2010 - IdentityType and DeviceType, created method toXMLMetadata
 *  22.12.2009 - Test to read the metadata
 *  17.12.2009 - Creates class
 *
 */

public class PublishReceive {
	
	/**
	 * Publish requests will transformed to data model publish requests. 
	 * 
	 * @param publish
	 * @return
	 * @throws SessionNotFoundException
	 * @throws NoSuchAlgorithmException
	 * @throws MetadataConstructionException 
	 * @throws InvalidMetadataException 
	 * @throws ParserConfigurationException
	 * @throws SAXException
	 * @throws IOException
	 */
	public static ResponseType publish(PublishRequestType publish)
					throws SessionNotFoundException, NoSuchAlgorithmException, 
					ParameterException, RequestCreationException, 
					IdentifierConstructionException, MetadataConstructionException, InvalidMetadataException {
		
		ConnectionContainer.getInstance().renewSession(publish.getSessionId());
		
		MessageTransformer mTransformer = MessageTransformer.getInstance();

		PublishRequest pr = mTransformer.transformPublishRequest(publish);
    		try {
				DeprecatedDataModelServiceAccessor.getDataModelServiceInstance()
																	.publish(pr);
			} catch (NoSuchPublisherException e) {
				// TODO Handle this exception
			}
		
		ResponseType rt = new ResponseType();
		rt.setPublishReceived(new ResponseType.PublishReceived());
		return rt;
	}
}