/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.communication.services.ssrc
 * File:    SearchReceive.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.communication.services.ssrc;

import java.security.NoSuchAlgorithmException;

import org.apache.log4j.Logger;
import org.trustedcomputinggroup._2010.ifmap._2.ResponseType;
import org.trustedcomputinggroup._2010.ifmap._2.SearchRequestType;
import org.trustedcomputinggroup._2010.ifmap._2.SearchResultType;

import de.fhhannover.inform.iron.mapserver.communication.DeprecatedDataModelServiceAccessor;
import de.fhhannover.inform.iron.mapserver.communication.connections.ConnectionContainer;
import de.fhhannover.inform.iron.mapserver.communication.services.ssrc.exceptions.SessionNotFoundException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.IdentifierConstructionException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.NoSuchPublisherException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.ParameterException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.RequestCreationException;
import de.fhhannover.inform.iron.mapserver.logging.Logging;
import de.fhhannover.inform.iron.mapserver.messages.SearchRequest;
import de.fhhannover.inform.iron.mapserver.messages.SearchResult;
import de.fhhannover.inform.iron.mapserver.utils.MessageTransformer;

/**
 * SearchReceive class
 * 
 * Manages the search requests and pass the searches to the data model
 * 
 * @author dl
 * @version 0.1
 * 
 * created: 10.02.2010
 *
 * changes:
 *  04.03.2010 - error responses
 *  14.02.2010 - cleanup
 *  10.02.2010 - created class, pass search to datamodel
 *  19.08.2010 - small changes as a SearchResult is returned
 *
 */

public class SearchReceive {
	private static Logger logger;
	static {
		logger = Logging.getTheLogger();
	}
	
	/**
	 * Transforms SearchRequestType in data model SearchRequest
	 * 
	 * @param search
	 * @return
	 * @throws SessionNotFoundException
	 * @throws NoSuchAlgorithmException
	 */
	public static ResponseType search(SearchRequestType search) 
	throws SessionNotFoundException, NoSuchAlgorithmException,
	RequestCreationException, ParameterException, IdentifierConstructionException {
		
		ConnectionContainer.getInstance().renewSession(search.getSessionId());
		
		SearchResultType searchRes = null;
		ResponseType ret = new ResponseType();
		MessageTransformer mTrans = MessageTransformer.getInstance();

		SearchResult searchResp = null;
		
		SearchRequest searchReq = mTrans.transformSearchRequest(search);
		try {
			searchResp = DeprecatedDataModelServiceAccessor.getDataModelServiceInstance()
																		.search(searchReq);
		} catch (NoSuchPublisherException e) {
			e.printStackTrace();
			// TODO Handle exception!
		}
		
		searchRes = mTrans.transformSearchResult(searchResp);
		ret.setSearchResult(searchRes);
		return ret;
	}
}